package AmiRNA::Error;

# Chained die propagate
#
# Reference: 
# brian d foy - Mastering Perl. Chapter 12: Detecting and Reporting Errors. O'Reilly 2007.

our $VERSION = '3.1';

sub new { bless $_[1], $_[0] }

sub PROPAGATE {
	my($self, $file, $line) = @_;

	$self->{chain} = [] unless ref $self->{chain};
	push @{ $self->{chain} }, [ $file, $line ];

	$self;
}

1;

__END__

=head1 NAME

AmiRNA::Error

=head1 SYNOPSIS

=head1 DESCRIPTION

Error handling using 'chained die propagate'.
Reference: brian d foy - Mastering Perl. Chapter 12: Detecting and Reporting Errors. O'Reilly 2007.

=head1 METHODS

=over

=item C<$results = AmiRNA::Config::ConfigParser-E<gt>new()>

Create AmiRNA::Error object

=item C<$results = AmiRNA::Config::ConfigParser-E<gt>PROPAGATE($file, $line)>

Propagate error message with file and line number where the error was thrown.

=back

=head1 AUTHOR

Stephan Ossowski, <stephan.ossowski@tuebingen.mpg.de>,
Markus Riester, <markus.riester@tuebingen.mpg.de>,
Joffrey Fitz, <joffrey.fitz@tuebingen.mpg.de>

=head1 LICENCE AND COPYRIGHT

Copyright (C) 2005-2006 by Max Planck Institute for Developmental Biology, 
Tuebingen.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.


=head1 DISCLAIMER OF WARRANTY

BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
NECESSARY SERVICING, REPAIR, OR CORRECTION.

IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
SUCH DAMAGES.

=cut

# vim: ft=perl sw=4 ts=4 expandtab
