#!/usr/bin/perl
#
#    WMD - A tool for miRNA target search and amiRNA design
#
#    Test program for WMD3 classes
#    Version 3.1
#
#    Authors: Stephan Ossowski, Joffrey Fitz, Markus Riester
#    Copyright (C) 2005-2009 by Max Planck Institute for Developmental Biology, Tuebingen.
##########################################################################################

use strict;
use warnings;

use Getopt::Std;

use AmiRNA::DB::Base;
use AmiRNA::DB::Results;
use AmiRNA::DB::Job;

# cmd line arguments:
#  -i id
#  -c configfile

our( $opt_c, $opt_i );
getopts('c:i:');

if(not defined($opt_c) or not defined($opt_i)) {
	print usage();
	exit;
}

eval {
	### Database connection
	my $db = AmiRNA::DB::Base->new( $opt_c );
	$db->connect();

	### Get amiRNA results from database
	my $results = AmiRNA::DB::Results->new( $db );
	my ($job, $mirna_objs) = $results->get($opt_i);


	### Process result objects
	foreach my $amiRNA ( @$mirna_objs ) {
		print   $amiRNA->{mirna_pattern} . "\t";
 		print $amiRNA->{absolute} . "\t";
 		print $amiRNA->{maybe} . "\t";
 		print $amiRNA->{relaxed_filter_32} . "\t";
 		print $amiRNA->{relaxed_filter_28_32} . "\t";
 		print $amiRNA->{mutations} . "\t";
		print $amiRNA->{optimal_energy} . "\t";
		print $amiRNA->{targets} . "\t";
 		print $amiRNA->{type} . "\t";
 		print $amiRNA->{score};
		print "\n";
	}

	$db->disconnect();
};
if($@) {
        print "Error: " . $@->{'msg'} . "\n" . $@->{'errno'} . "\n" . $@->{'subject'} . "\n";
        foreach my $x (@{ $@->{'chain'} } ) {
                foreach my $y ( @{ $x } ) { print "$y\n"; }
        }
}


exit 0;
#####################################################################################

sub usage {
	return <<EOT
$0 Version 3.1, Stephan Ossowski, Joffrey Fitz, Markus Riester 2008

Usage: $0 [Options] -i <result ID> -c <configfile>

Available Options:

-i      result table ID
-c      configfile 
--help	This help.

Example: $0 -i 1 -c /etc/AmiRNA/AmiRNA.xml

EOT
;
}
