#!/usr/bin/perl
#
#    WMD - A tool for miRNA target search and amiRNA design
#
#    Test program for WMD3 classes
#    Version 3.1
#
#    Authors: Stephan Ossowski, Joffrey Fitz, Markus Riester
#    Copyright (C) 2009 by Max Planck Institute for Developmental Biology, Tuebingen.
#####################################################################################

use strict;
use warnings;
use Getopt::Std;
use AmiRNA::TargetSearch::Vmatch;
use AmiRNA::Config::ConfigParser;

# cmd line arguments:
#  -c  configfile
our( $opt_c );
getopts('c:');

if ( (! defined $opt_c) ) {
        print usage();
        exit;
}


my $searchOptions;
eval {
	$searchOptions = AmiRNA::TargetSearch::SearchOptions->new($opt_c);
};
if ($@) {

	print "Some errors occured.\n";
	print "Start error message.\n" . $@->{'msg'} . "\n" . $@->{'errno'} . "\n" . $@->{'subject'} . "\n";
	foreach my $x (@{ $@->{'chain'} } ) { 
		foreach my $y ( @{ $x } ) { print "$y\n"; }
	}
	print "End error message.\n";
}
else {
	print "Ok.\n";
}
exit(0);


sub usage {
        return <<EOT
$0 Version 3.1, Stephan Ossowski, Joffrey Fitz, Markus Riester 2008

Usage: $0 -c config_file

Available Options:

-c      configfile, optional, default /etc/AmiRNA/AmiRNA.xml
--help  This help.

Correct example: $0 -c /etc/AmiRNA/AmiRNA.xml

Example with error: $0 -c /not/existing/directory/wrong.xml

EOT
;
}

