#!/usr/bin/perl
#
#    WMD - A tool for miRNA target search and amiRNA design
#
#    Test program for WMD3 classes
#    Version 3.1
#
#    Authors: Stephan Ossowski, Joffrey Fitz, Markus Riester
#    Copyright (C) 2005-2009 by Max Planck Institute for Developmental Biology, Tuebingen.
##########################################################################################

use strict;
use warnings;
use Getopt::Std;
use AmiRNA::Designer::OligoDesign;

my $query = 'ugacagaagagagugagcac';
my $oligo = AmiRNA::Designer::OligoDesign->new();

### Test A.thaliana RS300
my ($mirna_sen, $mirna_rev, $star_sen, $star_rev) = $oligo->RS300($query);
print "RS300:\n$mirna_sen\n$mirna_rev\n$star_sen\n$star_rev\n\n";

### Test A.thaliana updated RS300 with 21mer miRNA size
($mirna_sen, $mirna_rev, $star_sen, $star_rev) = $oligo->RS300_21mer($query);
print "New RS300:\n$mirna_sen\n$mirna_rev\n$star_sen\n$star_rev\n\n";

### Test Oryza sativa NW55
($mirna_sen, $mirna_rev, $star_sen, $star_rev) = $oligo->NW55($query);
print "NW55:\n$mirna_sen\n$mirna_rev\n$star_sen\n$star_rev\n\n";

### Test Clamydomonas reinhardtii pChlamyRNA2
my ($mirna, $mismatch_msg, $fwd_oligo_mm, $rev_oligo_mm) = $oligo->pChlamyRNA2($query);
print "pChlamyRNA2:\n$mirna\n$mismatch_msg\n$fwd_oligo_mm\n$rev_oligo_mm\n\n";


print "Finished oligo design test. Test was successful if you see 4 sets of oligos (RS300, New RS300, NW55, pChlamyRNA2).\n\n";
exit(0);
