#!/usr/bin/perl
#
#    WMD - A tool for miRNA target search and amiRNA design
#
#    Test program for WMD3 classes
#    Version 3.1
#
#    Authors: Stephan Ossowski, Joffrey Fitz, Markus Riester
#    Copyright (C) 2005-2009 by Max Planck Institute for Developmental Biology, Tuebingen.
##########################################################################################

use strict;
use warnings;
use File::Temp qw/ tempdir /;

### External binary
my $viennaRNA_path = "/usr/local/bin";
unless ( stat $viennaRNA_path) {
	die "$viennaRNA_path: Folder not found";
}


### Input and output variables for hybridization
my $seq_a = "TTAATTATGAGAACTATGCGC";
my $seq_b = "GGGCATAGTTCTCATAATTAA";
my $temperature = "23";
my $dg = 0;
my $sum = 0;


### tmp path for writing files
my $tmppath = "./";
chdir( $tmppath );


### Create input format for RNAcofold and RNAup
my $linked_seq   = $seq_a . "&" . $seq_b;
$linked_seq =~ tr/tT/uU/;


### Write temporary input file for RNAcofold
my $tmp = new File::Temp(DIR => $tmppath);
my @folder_structure = split("/", $tmp);
my $filename = pop(@folder_structure);
print $tmp ">$filename\n$linked_seq";

### Hybridize with RNAcofold
my $command = "$viennaRNA_path/RNAcofold -noCloseGU -noLP -T $temperature < $tmp";
print "\n\nExecuting command: $command\n\n";
my $res = `$command`;

( $dg ) = $res =~ /\(\s*([0-9\-\.]*?)\)$/;
print "RNAcofold dG: $dg\n";


### Write temporary input file for RNAup
my $tmp2 = new File::Temp(DIR => $tmppath);
my @folder_structure2 = split("/", $tmp2);
my $filename2 = pop(@folder_structure2);
print $tmp2 ">$filename2\n$linked_seq";

### Hybridize with RNAup
$command = "$viennaRNA_path/RNAup -Xp -noCloseGU -noLP -T $temperature < $tmp2";
print "\n\nExecuting command: $command\n\n";
$res = `$command`;

### Parse RNAup results
my @result_lines = split("\n", $res);
my ($energy_formula) = $result_lines[1] =~ /\((\-.*)\)/;
($dg, $sum) = split(/=/, $energy_formula);
my ($dg_int, $dg_mRNA, $dg_sRNA) = split(/\+/, $sum);
$dg =~ s/ //g; $dg_int =~ s/ //g; $dg_mRNA =~ s/ //g;

print "RNAcofold dG: $dg\n\n";

print "Finished testing ViennaRNA tools RNAcofold and RNAup.\n";
print "Both tools work if you see two energy values and 2 output files (one text file and on postscript file).\n\n";

exit 0;
