#!/usr/bin/perl
#
#    WMD - A tool for miRNA target search and amiRNA design
#
#    Test program for WMD3 classes
#    Version 3.1
#
#    Authors: Stephan Ossowski, Joffrey Fitz, Markus Riester
#    Copyright (C) 2005-2009 by Max Planck Institute for Developmental Biology, Tuebingen.
##########################################################################################

use strict;
use warnings;
use Getopt::Std;
use Bio::Seq;
use AmiRNA::TargetSearch::ViennaRNA;

# cmd line arguments:
# -t  temperature
# -c  configfile
our( $opt_t, $opt_c );
getopts('t:c:');

unless ( defined($opt_t) && defined($opt_c) ) {
	print usage();
	exit;
}

my $seq_a = "ugacagaagagagugagcac";
my $seq_b = "gugcucacucucuucuguca";

my $folding = AmiRNA::TargetSearch::ViennaRNA->new($opt_c, $opt_t,);

my $dG = $folding->RNAcofold($seq_a, $seq_b);
print "\n\nRNAcofold: $dG\n\n";

$dG = $folding->RNAup($seq_a, $seq_b);
print "\n\nRNAup: $dG\n\n";

exit(0);

sub usage {
	return <<EOT
$0 Version 3.0, Stephan Ossowski, Joffrey Fitz, Markus Riester 2008

Usage: $0 [Options] -c <configfile> -t <temperature>

Available Options:
-c      config file
-t      folding temperature
--help	this help.	

Example: $0 -c /etc/AmiRNA/AmiRNA.xml -t 23
EOT
;
}	
