#!/usr/bin/perl
###############################################################################
#
# amirna_initdb.pl - Initializes database tables for the AmiRNA package
#
# Version: 3.1
#
# Authors: 
#	Joffrey Fitz <joffrey.fitz@tuebingen.mpg.de>
#	Stephan Ossowski <stephan.ossowski@tuebingen.mpg.de>
#
# Copyright (c) 2009 Max Planck Institute for Developmental Biology, 
# 	http://www.eb.tuebingen.mpg.de
#
# This program is free software; you can redistribute it and/or modify it                        
# under the terms of the GNU General Public License as published by the Free                     
# Software Foundation; either version 2, or (at your option) any later 
# version.
#
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
# or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
# for more details.
#
###############################################################################

use strict;
use warnings;

use Getopt::Std;
use AmiRNA::Config::ConfigParser;
use AmiRNA::DB::Base;
use AmiRNA::DB::Job;
use AmiRNA::DB::Queue;
use AmiRNA::DB::Results;
use AmiRNA::DB::Sequences;


our( $opt_c, $opt_d );
getopts('c:d');
# unless ( defined($opt_f) && defined($opt_t) ) {
# 	print usage();
# 	exit;
# }

eval {
	### Connect to database
	my $db = AmiRNA::DB::Base->new($opt_c);
	$db->connect();

	my ($db_name, $db_host, $db_engine);
	if($db->{engine} =~ /^SQLite$/i) {
		$db_engine = "sqlite";
		$db->{dsn} =~ /dbname=(.*)$/;
		$db_name = $1;
	}
	elsif($db->{engine} =~ /^MySQL$/i) {
		$db_engine = "mysql";
		$db->{dsn} =~ /database=(.*)$/;
		$db_name = $1;
		$db_name =~ s/;.*$//;
		$db->{dsn} =~ /host=(.*)$/;
		$db_host = $1;
		$db_host  =~ s/;.*$//;
	}
	else {
		print "Error: Unsupported SQL engine: " . $db->{engine }. "\n";
		exit(1);
	}
	
		
	my $queue = AmiRNA::DB::Queue->new($db);
	my $results = AmiRNA::DB::Results->new($db);
	my $sequences = AmiRNA::DB::Sequences->new($db);
	
	### Drop tables
 	if(defined($opt_d)) {
 		if($db_engine eq "sqlite") {
 			print "Do you really want to delete all tables in $db_name (this will wipe out all your results)? (Y/n)  ";
		} elsif($db_engine eq "mysql") {
 			print "Do you really want to delete $db_name tables on $db_host (this will wipe out all your results)? (Y/n) ";
		}
		my $input = <STDIN>;
		chomp $input;
		if(not($input eq "y" or $input eq "Y" or $input eq "yes" or $input eq "Yes")) {
			print "Exiting.\n";
			exit;
		}
		print "Deleting queue\n";
 		$queue->drop_table();
		print "Deleting results\n";
  		$results->drop_table();
		print "Deleting sequences\n";
  		$sequences->drop_table();
 	}

	### Create tables Queue, Results
 	$queue->create_table();
	$results->create_table();
        $sequences->create_table();	
	$db->disconnect();

};
if($@) {
	print "Error: " . $@->{'msg'} . "\n" . $@->{'errno'} . ": " . $@->{'subject'} . "\n";
# 	foreach my $x (@{ $@->{'chain'} } ) {
# 		foreach my $y ( @{ $x } ) { print "$y\n"; }
# 	}
	exit 1;
}

exit(0);

sub usage {
	return <<EOT
$0 Version 3.1, Stephan Ossowski, Joffrey Fitz, Markus Riester 2008

Usage: $0 [-d] [-c configfile]

Available Options:
################################################################################

-d    delete tables (optional)
-c    configfile (optional)
--help	This help.	

EOT
;
}	
