package WMD3::Plugins::Hybridize::Backend;

###############################################################################
#
# Hybridize::Backend
#
# Version 3.1
#
# Author: Joffrey Fitz <joffrey.fitz@tuebingen.mpg.de>
#		  Stephan Ossowski <stephan.ossowski@tuebingen.mpg.de>
#         Markus Riester
#		  
# Copyright (c) 2008 Max Planck Institute for Developmental Biology, 
# 	http://www.eb.tuebingen.mpg.de
#
# This program is free software; you can redistribute it and/or modify it                        
# under the terms of the GNU General Public License as published by the Free                     
# Software Foundation; either version 2, or (at your option) any later 
# version.
#
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
# or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
# for more details.
#
###############################################################################

use strict;
use warnings;

require      Exporter;

use File::Temp qw/ tempdir /;
use File::Basename;
use Cwd;

our @ISA       = qw(Exporter);
our @EXPORT    = qw(rnafold_img);


##############################################################################
#
# rnafold_img
# returns path to png 
#
##############################################################################

sub rnafold_img {
	my ($self, $seq_a, $seq_b, $temperature) = @_;
	
	# external binaries
	my $rnacofold_bin = $self->{conf}{Plugins}{Plugin}('name', 'eq', 'Hybridize')->{rnacofold_location};
	my $convert_bin   = $self->{conf}{Plugins}{Plugin}('name', 'eq', 'Hybridize')->{convert_location};
	
	unless ( stat $rnacofold_bin) {
		die "$rnacofold_bin: File not found";
	}
	unless ( stat $convert_bin) {
		die "$convert_bin: File not found";
	}
		
	# temporary dirs
	my $template = "wmd3_" . time . "_XXXXXXX";
	my $webroot  = $self->{conf}{web_app}{webroot};
	my $dir      = $self->{conf}{Plugins}{Plugin}('name', 'eq', 'Hybridize')->{tmp_dir};
	my $tempdir_prefix = $webroot . "/" . $dir;
	print STDERR "Using template $template\n";
	print STDERR "Using dir $tempdir_prefix\n";
	
	my $tempdir = tempdir( $template, DIR => $dir, CLEANUP => 1 );
	
	my $linked_seq   = $seq_a . "&" . $seq_b;
	my $seq_filename = "seq.txt";
	
	my $cwd = cwd;
	chdir( $tempdir );
	open(OUT, ">$seq_filename") or die;
	print OUT "$linked_seq";
	close(OUT);
	
	my $rnacofold_cmd = $rnacofold_bin . " -T $temperature < $seq_filename";
	my $res = `$rnacofold_cmd`;
	if($?) {
		die "RNAcofolderror: $?\n command: $rnacofold_cmd";
	}
	
	my $convert_cmd = $convert_bin . " rna.ps rna.png";
	$res = `$convert_cmd`;
	if($?) {
		die "convert: $?\n command: $convert_cmd";
	}
	
	# restore working directory
	chdir($cwd);
	
	return $tempdir . "/" . "rna.png";
}

1;