package Oligo;

###############################################################################
#
# Oligo.pm
#
# Version 3.1
#
# Author: Joffrey Fitz <joffrey.fitz@tuebingen.mpg.de>
#
# Copyright (c) 2008 Max Planck Institute for Developmental Biology, 
# 	http://www.eb.tuebingen.mpg.de
#
# This program is free software; you can redistribute it and/or modify it                        
# under the terms of the GNU General Public License as published by the Free                     
# Software Foundation; either version 2, or (at your option) any later 
# version.
#
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
# or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
# for more details.
#
###############################################################################
use strict;

use base 'WMD3::WebApp::Base';
use WMD3::WebApp::Widgets;
use WMD3::Plugins::Oligo::Backend;

use constant ID          => 3;
use constant PLUGIN_NAME => 'Oligo';


use Data::Dumper;
###############################################################################



sub setup {
	my $self = shift;
	$self->start_mode('showform');
	$self->run_modes(
			'showform' => 'showform',
			'compute' => 'compute',
	);
}

# Execute the following before we execute the requested run mode
sub cgiapp_prerun {
	my $self = shift;

	# Get CGI query object
	my $q = $self->query();
	# Load configuration for plugin and store it
	$self->load_plugin_conf(PLUGIN_NAME);
	# Set current project
	$self->set_project( $q->param('project') || $self->{conf}{web_app}{standard_project} );
	# Setup title, menubar, etc.
	$self->init_view();
}


sub teardown {
}

sub showform {
	my $self = shift;
	
	# Get CGI query object
	my $q = $self->query();
	my $full_url = $q->url(-relative => 1) . "?page=" . ID;
	
	my @vectors = @{ $self->{conf}{Plugins}{Plugin}('name', 'eq', 'Oligo')->{vectors}{vector} };

	$self->stash->{vector_popup_menu} = $q->popup_menu
		(
			-name    => 'vector',
			-id      => 'vector',
			-values  => \@vectors,
			-default => 'RS300',
			-class   => 'form_widget',
		);
 
 	# Set the form
	#
	# Add a POST form and hidden parameters
	$self->stash->{start_form} = $q->start_multipart_form;
	$self->stash->{hidden_fields} = $q->hidden('page', $self->{_plugin_name} )
		. $q->hidden('project', $self->get_current_project )
		. $q->hidden('rm', "compute" );
	$self->stash->{end_form} = $q->endform;
	
	$self->stash->{template} = $self->load_tmpl($self->plugin_conf('template_path').'/view.tmpl');

	return;
}

sub compute {
	my $self = shift;
	
	# Check for user input errors
	if(not $self->check_input_data) {
		# Redirect to form
		$self->showform();
	
		return;
	}
	
	# Get CGI query object
	my $q = $self->query();
	my $full_url = $q->url(-relative => 1) . "?page=" . ID;
	
	# collect parameters from ENV
	my %user_param;
	foreach my $param ($q->param) {
		$user_param{$param} = $q->param($param);
	}
	# remove webapp specific parameters
	my $query = $user_param{'q'};
	delete @user_param{"rm", "project", "page", "query"};
	
	my $html;
# 	foreach my $key (sort keys %user_param) {
# 		$html .= "<b>$key</b> => " . $user_param{$key} . "<br>";
# 	}
	
	# perform target search
	$html .= search($self, $user_param{'q'}, $user_param{'vector'} );

	$self->stash->{params} = $html;
	
	$self->stash->{template} = $self->load_tmpl($self->plugin_conf('template_path').'/results.tmpl');

	return;
}

sub check_input_data {
	my $self = shift;
	my $q    = $self->query;

	my $err  = 1;

	# There must be input specified in the search field
	if(! $q->param('q') ) {
		$self->stash->{error_msg} = $self->print_error_div("Please specify a mircoRNA sequence.");
		$err = 0;
	}
	
	return $err;
}


1;
