package WMD3::Plugins::Oligo::Backend;

###############################################################################
#
# Oligo::Backend
#
# Version 3.1
#
# Author: Joffrey Fitz <joffrey.fitz@tuebingen.mpg.de>
#		  Stephan Ossowski <stephan.ossowski@tuebingen.mpg.de>
#         Markus Riester
#		  
# Copyright (c) 2008 Max Planck Institute for Developmental Biology, 
# 	http://www.eb.tuebingen.mpg.de
#
# This program is free software; you can redistribute it and/or modify it                        
# under the terms of the GNU General Public License as published by the Free                     
# Software Foundation; either version 2, or (at your option) any later 
# version.
#
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
# or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
# for more details.
#
###############################################################################

use strict;
use warnings;

use AmiRNA::Designer::OligoDesign;
use WMD3::WebApp::Error;
use AmiRNA::Error;

require      Exporter;

our @ISA       = qw(Exporter);
our @EXPORT    = qw(search);


##############################################################################
#
# get_accession_list()
#
##############################################################################

sub search {
	my ($self, $seq, $vector) = @_;
	
	my $oligo = AmiRNA::Designer::OligoDesign->new();
	
	my $html;

	if($vector eq "RS300 (MIR319a Arabidopsis thaliana)") {
		my ($mirna_sen, $mirna_rev, $star_sen, $star_rev);
		eval {
			($mirna_sen, $mirna_rev, $star_sen, $star_rev) = $oligo->RS300($seq);
		};
		return process_error() if ($@);
		
		$html = qq(
			<h3>Oligos for amiRNA \"$seq\"</h3>
			<p>
			<code>
			I miR-s $mirna_sen<br/> 
			II miR-a $mirna_rev<br/>
			III miR*s $star_sen<br/>
			IV miR*a $star_rev<br/>
			</code>
			</p>
		);

	}

	elsif($vector eq "RS300 21mer (MIR319a Arabidopsis thaliana)") {
		my ($mirna_sen, $mirna_rev, $star_sen, $star_rev);
		eval {
			($mirna_sen, $mirna_rev, $star_sen, $star_rev) = $oligo->RS300_21mer($seq);
		};
		return process_error() if ($@);

		$html = qq(
			<h3>Oligos for amiRNA \"$seq\"</h3>
			<p>
			<code>
			I miR-s $mirna_sen<br/> 
			II miR-a $mirna_rev<br/>
			III miR*s $star_sen<br/>
			IV miR*a $star_rev<br/>
			</code>
			</p>
		);
	}

	elsif($vector eq "NW55 (MIR528 Oryza sativa)") {
		my ($mirna_sen, $mirna_rev, $star_sen, $star_rev);
		eval {
			($mirna_sen, $mirna_rev, $star_sen, $star_rev) = $oligo->NW55($seq);
		};
		return process_error() if ($@);
		
		$html = qq(
			<h3>Oligos for amiRNA \"$seq\"</h3>
			<p>
			<code>
			I miR-s $mirna_sen<br/> 
			II miR-a $mirna_rev<br/>
			III miR*s $star_sen<br/>
			IV miR*a $star_rev<br/>
			</code>
			</p>
		);
	}
	elsif($vector eq "pChlamiRNA2 and 3 (MIR1157 Chlamydomonas reinhardtii)") {
		my ($mirna, $mismatch_msg, $fwd_oligo_mm, $rev_oligo_mm);
		eval {
			($mirna, $mismatch_msg, $fwd_oligo_mm, $rev_oligo_mm) = $oligo->pChlamyRNA2($seq);
		};
		return process_error() if ($@);
		
		$html = qq(
			<h3>Oligos for amiRNA (DNA form): \"$mirna\"</h3>
			<p>
			<code>
			MISMATCH AT POS 5/6 OF MIRNA $mismatch_msg<br /><br />
			amiFor_mm 5' $fwd_oligo_mm 3' <br />
			amiRev_mm 5' $rev_oligo_mm 3'<br />
			</code>
			</p>
		);
	}

 	return $html;
}

1;
