package WMD3::Plugins::TargetSearch::AmiRNAGfx;

###############################################################################
#
# WMD3::Plugins::TargetSearch::AmiRNAGfx
#
# Author: Joffrey Fitz <joffrey.fitz@tuebingen.mpg.de>
#		  
# Copyright (c) 2008 Max Planck Institute for Developmental Biology, 
# 	http://www.eb.tuebingen.mpg.de
#
# This program is free software; you can redistribute it and/or modify it                        
# under the terms of the GNU General Public License as published by the Free                     
# Software Foundation; either version 2, or (at your option) any later 
# version.
#
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
# or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
# for more details.
#
###############################################################################

use GD;

# Image dimensions
our $img_dimx    = 700;
our $img_dimy    = 100;
our $margin_left = 20;
our $margin_right= 20;


sub new {
	my $class = shift;

	my $self = {};
	bless($self, $class);
 
	$self->init_img();
	
	bless($self);
	return $self;
}

sub init_img {
	my $self = shift;
	
	# Truecolor image
	$img = new GD::Image($img_dimx+$margin_right+$margin_left,$img_dimy+1, 1);
	$img->interlaced('true');
		
	%colors = ( 
		white => $img->colorAllocate(255,255,255),
		black => $img->colorAllocate(0,0,0),
		blue  => $img->colorAllocate(0,153,255),
		red   => $img->colorAllocate(255,0,0),
		grey  => $img->colorAllocate(200,200,200),
		light_blue_alpha => $img->colorAllocateAlpha(210,229,255, 180)
	);
	
	$self->{colors} = %colors;
	$self->{img} = $img;
}

sub draw {
	my ($self, $gene_start, $gene_end, $target_start, $target_length) = @_;
	
	$self->{gene_start}    = $gene_start;
	$self->{gene_end}      = $gene_end;
	$self->{target_start}  = $target_start;
	$self->{target_length} = $target_length;
	$self->{factor}        = $gene_end/$img_dimx;

	# Draw background layer
	$img->filledRectangle(0,0,$img_dimx+50,$img_dimy+1, $colors{white});
	
	$self->draw_ruler;
	$self->draw_gene;
	$self->draw_target_spot;
	$self->draw_target;
}

sub draw_ruler {
	my $self = shift;
	
	my $y_offset = 18;
	my $tick_len = 6;
	my $text_pos = $y_offset-$tick_len-12-2;
	
	# scale
	my ($gene_end, $target_start, $gene_end_pos, $target_start_pos);
	if($self->{gene_end} < $img_dimx) {
		$gene_end = $self->{gene_end};
		$target_start = $self->{target_start};
		$gene_end_pos = $gene_end;
		$target_start_pos = $target_start;
	} else {
		$gene_end = $self->{gene_end}/$self->{factor};
		$target_start = $self->{target_start}/$self->{factor};
		$gene_end_pos = $gene_end*$self->{factor};
		$target_start_pos = $target_start*$self->{factor};
	}
	
	# line
	$self->{img}->line($self->{gene_start}, $y_offset, $gene_end, $y_offset, $colors{black});
	# Ticks: 
	# gene_start
	$self->{img}->line($self->{gene_start}, $y_offset-$tick_len, $self->{gene_start}, $y_offset, $colors{black});
	$self->{img}->string(gdSmallFont,$self->{gene_start}, $text_pos, $self->{gene_start}, $colors{black});
	
	# target_start
	$self->{img}->line($target_start, $y_offset-$tick_len, $target_start, $y_offset, $colors{black});
	$self->{img}->string(gdSmallFont,$target_start, $text_pos, $target_start_pos, $colors{black});
	
	# gene_end
	$self->{img}->line($gene_end, $y_offset-$tick_len, $gene_end, $y_offset, $colors{black});
	$self->{img}->string(gdSmallFont, $gene_end, $text_pos, $gene_end_pos, $colors{black});
}

sub draw_gene {
	my $self = shift;
	my $gene_y_offset = 38;
	my $arrow_length = 12;
	my $gene_height = 8;
	
	# scale
	my ($gene_end, $target_start, $gene_end_pos, $target_start_pos);
	if($self->{gene_end} < $img_dimx) {
		$gene_end = $self->{gene_end};
	} else {
		$gene_end = $self->{gene_end}/$self->{factor};
	}

	# make a polygon aka gene
	my $poly = new GD::Polygon;
	$poly->addPt($self->{gene_start}, $gene_y_offset);
	$poly->addPt($gene_end-$arrow_length, $gene_y_offset);
	$poly->addPt($gene_end, $gene_y_offset + ($gene_height/2) );
	$poly->addPt($gene_end-$arrow_length, $gene_y_offset + $gene_height);
	$poly->addPt($self->{gene_start}, $gene_y_offset + $gene_height);
	
	# draw the polygon, filling it with a color
	$self->{img}->filledPolygon($poly, $colors{blue});
}

sub draw_target {
	my $self = shift;
	my $target_y_offset = 53;
	my $target_height = 8;
	
	# scale
	my ($target_start, $target_length);
	if($self->{gene_end} < $img_dimx) {
		$target_start = $self->{target_start};
		$target_length = $self->{target_length};
	} else {
		$target_start = $self->{target_start}/$self->{factor};
		$target_length = $self->{target_length}/$self->{factor};
	}
	
	$self->{img}->filledRectangle($target_start, $target_y_offset, $target_start+$target_length, $target_y_offset+$target_height, $colors{red});
	
	for(my $x=$target_start; $x<= ($target_start+$target_length); $x+=3) {
		$self->{img}->line($x, $target_y_offset-1, $x, $target_y_offset-8, $colors{grey});	
	}
}

sub draw_target_spot {
	my $self = shift;
	
	# scale
	my ($target_start, $target_length);
	if($self->{gene_end} < $img_dimx) {
		$target_start = $self->{target_start};
		$target_length = $self->{target_length};
	} else {
		$target_start = $self->{target_start}/$self->{factor};
		$target_length = $self->{target_length}/$self->{factor};
	}
	
	my $radius = $target_length/2;
	my $midpoint_x = $target_start+ ($target_length/2);
	my $midpoint_y = 51;
	
	$img->alphaBlending(1);
	$img->filledEllipse($midpoint_x,$midpoint_y,$radius+50,$radius+28, $colors{light_blue_alpha});
}

1;
