package WMD3::WebApp::Base;

###############################################################################
#
# WMD3::WebApp::Base
#
# Version 3.1
#
# Author: Joffrey Fitz <joffrey.fitz@tuebingen.mpg.de>
#
# Copyright (c) 2009 Max Planck Institute for Developmental Biology, 
# 	http://www.eb.tuebingen.mpg.de
#
# This program is free software; you can redistribute it and/or modify it                        
# under the terms of the GNU General Public License as published by the Free                     
# Software Foundation; either version 2, or (at your option) any later 
# version.
#
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
# or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
# for more details.
#
###############################################################################

use base 'CGI::Application';
use strict;
use warnings;

use Data::Dumper;
use XML::Smart;

use CGI::Application::Plugin::DBH (qw/dbh dbh_config/);
use CGI::Application::Plugin::View::HTML::Template;
use CGI::Application::Plugin::Stash;


# configuration for plugins is stored here
my %plugin_conf;
my $current_project;
my $XML;

# CGI Application stuff
sub cgiapp_init {
	my $self = shift;
	
	# Load XML config file
	$XML = XML::Smart->new( $self->param('cfg_file') );
	## Change the root:
	$XML = $XML->{config};
	$self->{conf} = $XML;	
}

# Define our run modes
sub setup {
	my $self = shift;
	$self->start_mode('showform');
	$self->run_modes(
		'showform' => 'showform',
		'compute' => 'compute',
	);
}

# Execute the following before we execute the requested run mode
sub cgiapp_prerun {
	my $self = shift;

	# Get CGI query object
	my $q = $self->query();
	# Load configuration for plugin and store it
	$self->load_plugin_conf($self->PLUGIN_NAME);
	# Set current project
	$self->set_project( $q->param('project') || $self->{conf}{web_app}{standard_project} );
	# Setup title, menubar, etc.
	$self->init_view();
	# Prepare database connection
	my ($dsn, $usr, $pass) = ($self->config_get_dsn, $self->config_get_dbuser, $self->config_get_dbpass);
	$self->dbh_config("$dsn", "$usr", "$pass") || die;
}


# Loads and stores the configuration for a plugin
sub load_plugin_conf {
	my ($self, $plugin_name) = @_;
	$self->{_plugin_conf} = $self->{conf}->{Plugins}{Plugin}('name','eq',$plugin_name);
	$self->{_plugin_name} = $plugin_name;
	die  "*** Base.pm:load_plugin_conf(): No configuration found for module '$plugin_name'." if not defined $self->{conf}->{Plugins}{Plugin}('name','eq',$plugin_name);
}

# Returns plugin configuration values for given key, e.g.
# desc = $self->plugin_conf('description');
sub plugin_conf {
	my ($self, $param) = @_;

	return $self->{_plugin_conf}->{$param};
}

# Sets/gets the current project
sub set_project {
	my ($self, $project) = @_;
	$self->{_current_project} = $project; 
}

sub get_current_project {
	my $self = shift;
	return $self->{_current_project}; 
}

sub set_plugins {
	my ($self, %plugins) = @_;
	%{$self->{plugins}} = %plugins;
}

sub print_plugins {
	my $self = shift;

	# Get CGI query object
	my $q = $self->query();
	my $full_url = $q->url(-relative => 1);

	my @plugin_list;
	foreach my $value (sort keys %{$self->{plugins}}) {
		my $menu_link = "<a href=\"$full_url?page=" . $self->{plugins}{$value} . "\">" . $self->{plugins}{$value} . "</a>";
		push(@plugin_list, $menu_link);
	}
	return @plugin_list;
}

# Process any fatal errors
sub error {
	my $self  = shift;
	my $error = shift;
	return "There has been an error: $error";
}

sub init_view {
	my $self = shift;
	
	# Set the headline and title (defined in ../../StdTmpl/wmd3_[header|footer].tmpl)
	$self->stash->{htdocs} = $self->{conf}{web_app}{htdocs};
	$self->stash->{cgi} = $self->{conf}{web_app}{cgi};
	$self->stash->{headline} =  "<i>POLY<b>MORPH<sup><font style=\"font-size:small; color:#E5ED54;\"> beta</sup></b></i.";
	$self->stash->{tabbar} = $self->print_poly_tabs( $self->get_current_project(),  $self->{_plugin_name});
	$self->stash->{title} =  $self->plugin_conf('long_description')?$self->plugin_conf('long_description'):$self->plugin_conf('description');
}


1;
