package WMD3::WebApp::Widgets;

###############################################################################
#
# WMD3::WebApp::Widgets
#
# Version 3.1
#
# Author: Joffrey Fitz <joffrey.fitz@tuebingen.mpg.de>
#
# Copyright (c) 2009 Max Planck Institute for Developmental Biology, 
# 	http://www.eb.tuebingen.mpg.de
#
# This program is free software; you can redistribute it and/or modify it                        
# under the terms of the GNU General Public License as published by the Free                     
# Software Foundation; either version 2, or (at your option) any later 
# version.
#
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
# or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
# for more details.
#
###############################################################################

use strict;
use warnings;

require      Exporter;
use Data::Dumper;

our @ISA       = qw(Exporter);
our @EXPORT    = qw(print_poly_menu_test print_poly_menus print_poly_tabs print_project_combobox print_accessions_list 
					print_quality_combobox print_gbrowse_button print_start_end_pos_fields 
					print_chromsomes_combobox print_gbrowse_link print_adf_link print_primer_designer_button
					print_feature_combobox print_error_div);


##############################################################################
#
# print_poly_tabs
#
#	Used for WMD
#
#	This function generates some tabbar HTML, e.g.
#
#   <ul class="tab">
#   <li class="active"><a href="home.html"><span>Home </span></a></li>
# 	<li><a href="community.html"><span>Target search</span></a></li>
# 	<li><a href="blog.html"><span>Designer</span></a></li>
# 	<li><a href="messages.html"><span>Oligo</span></a></li>
# 	<li><a href="contact.html"><span>Hybridize</span></a></li>
# 	<li><a href="contact.html"><span>Help</span></a></li>
# 	<li><a href="contact.html"><span>Contact</span></a></li>
# 	</ul>
##############################################################################
sub print_poly_tabs {
	my ($self, $project, $plugin_name) = @_;

	my %menu;
	
	my $html_buf = "<!-- Toolbar-->\n<ul id=\"nav\" class=\"tab\">";
	my @menus = $self->{conf}{Menubar}{Project}('name','eq',$project)->{Menu}('[@]','name');
	foreach my $menu (@menus) {

		# Get items for Menu
		my @items = $self->{conf}->{Menubar}{Project}('name','eq',$project)->{Menu}('name','eq',$menu)->{Item}('[@]');
		foreach my $item (@items) {
			# Is plugin already loaded? If not, skip it
			my @res = grep(/$item/, (values %{$self->{plugins}} ));
			if(scalar(@res) == 1) {
				$menu{$self->{conf}{Menubar}{Project}('name','eq',$project)->{Menu}('name','eq',$menu)->{Pos}} = $menu;
				
				if($menu eq $plugin_name) {
					$html_buf .= '<li class="active"><a href="?page=' . $item . ";project=" . $self->get_current_project . '"><span>' . $self->{conf}{Plugins}{Plugin}('name','eq',$item)->{description} . '</span></a></li>' . "\n";
				}
				else {
					$html_buf .= '<li><a href="?page=' . $item . ";project=" . $self->get_current_project . '"><span>' . $self->{conf}{Plugins}{Plugin}('name','eq',$item)->{description} . '</span></a></li>' . "\n";
				}

			} else {
				print STDERR "!!! Widgets.pm:print_poly_menus(): Plugin '$item' not loaded. (@res)\n";
			}
		}
	}
	$html_buf .= '</ul>';

	return $html_buf;
}

##############################################################################
#
# print_error_div(error_msg)
#	@return: html with styled error div (css: error_msg)
#
#	used by WMD3
#
##############################################################################

sub print_error_div {
	my $self = shift;
	my $msg = shift;
	my $q = $self->query();
	
	return "<div class=\"error_msg\">" . $msg . "</div>";
}

##############################################################################
#
# print_project_combobox()
#	@return: html form with popup menu containing valid projects
#			 and submit button
#
##############################################################################
sub print_project_combobox {
	my $self = shift;
	my $q = $self->query();

	my @projects = $self->config_get_projects();
	
	my $project_combobox;

	$project_combobox  = $q->start_multipart_form;
	$project_combobox .= "<table border=0 cellpadding=0 cellspacing=0><tr><td>";
	# Add the combo
	$project_combobox .= $q->popup_menu( -name => 'project',
                            				-values => \@projects,
                            				-default => $self->get_current_project);
	# Add a hidden field for current plugin name
	$project_combobox .= $q->hidden('page', $self->{_plugin_name} );
	$project_combobox .= "</td><td>";
	# Add submit button
	$project_combobox .= $q->submit('Action','Change');
	$project_combobox .= "</td></tr></table>";
	$project_combobox .= $q->endform;


	return $project_combobox;
}


1;
