#!/usr/bin/perl -w

###############################################################################
#
# webapp.cgi
#
# Author: Joffrey Fitz <joffrey.fitz@tuebingen.mpg.de>
#
# Copyright (c) 2009 Max Planck Institute for Developmental Biology, 
# 	http://www.eb.tuebingen.mpg.de
#
# This program is free software; you can redistribute it and/or modify it                        
# under the terms of the GNU General Public License as published by the Free                     
# Software Foundation; either version 2, or (at your option) any later 
# version.
#
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
# or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
# for more details.
#
###############################################################################

use strict;
use WMD3::WebApp::Base;

# Specify custom lib (for AmiRNA)
use lib "../AmiRNA/lib/";

use constant DEBUG => 1;

my $config_file = 'wmd3.xml';
my $plugins_subdir = 'WMD3/Plugins';
my $plugins_dir =  './' . $plugins_subdir;

opendir(DIR, $plugins_dir) || die "can't opendir $plugins_dir: $!";
my @plugins = grep { /^[^\.].*\.pm$/ && -f "$plugins_dir/$_" } readdir(DIR);
closedir DIR;

my %plugins_h = ();

# Load all Plugins
# Paradigma: Everything is a plugin, even 'Home' and 'About' pages
foreach ( @plugins ) {
	s/\.pm$//;
	my $module = "WMD3/Plugins/" . $_ . ".pm";
	require $module;

	$_  = $_->new(PARAMS => { cfg_file => $config_file, conf => '', plugin_conf => '' });
	$plugins_h{$_->ID} = $_->PLUGIN_NAME;
}


my $page = "Home"; # Home is the start page

foreach my $plugin ( @plugins ) {
	$page = $plugin->query->param('page') if $plugin->query->param('page');

	if ($page eq $plugin->PLUGIN_NAME) {
		$plugin->set_plugins(%plugins_h);
		$plugin->run();
	}
}
