package Blast;

###############################################################################
#
# Blast.pm
#
# Version 3.1
#
# Author: Joffrey Fitz <joffrey.fitz@tuebingen.mpg.de>
#
# Copyright (c) 2008 Max Planck Institute for Developmental Biology, 
# 	http://www.eb.tuebingen.mpg.de
#
# This program is free software; you can redistribute it and/or modify it                        
# under the terms of the GNU General Public License as published by the Free                     
# Software Foundation; either version 2, or (at your option) any later 
# version.
#
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
# or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
# for more details.
#
###############################################################################

use base 'WMD3::WebApp::Base';

use strict;

use WMD3::WebApp::Widgets;
use WMD3::Plugins::Blast::Backend;
use WMD3::WebApp::Error;

use constant ID          => 5;
use constant PLUGIN_NAME => 'Blast';


use Data::Dumper;
###############################################################################



sub setup {
	my $self = shift;
	$self->start_mode('showform');
	$self->run_modes(
			'showform' => 'showform',
			'compute' => 'compute',
	);
}

# Execute the following before we execute the requested run mode
sub cgiapp_prerun {
	my $self = shift;

	# Get CGI query object
	my $q = $self->query();
	# Load configuration for plugin and store it
	$self->load_plugin_conf(PLUGIN_NAME);
	# Set current project
	$self->set_project( $q->param('project') || $self->{conf}{web_app}{standard_project} );
	# Setup title, menubar, etc.
	$self->init_view();
}


sub teardown {
}

sub showhome {
	my $self = shift;
	
	# Get CGI query object
	my $q = $self->query();
	my $full_url = $q->url(-relative => 1) . "?page=" . ID;
	
	$self->stash->{template} = $self->load_tmpl($self->plugin_conf('template_path').'/view.tmpl');

	return;
}

sub showform {
	my $self = shift;
	
	# Get CGI query object
	my $q = $self->query();
	my $full_url = $q->url(-relative => 1) . "?page=" . ID;
	
	# SearchOptions object
	my $searchOptions;
	my %local_dbs_description;
	eval {
		$searchOptions = AmiRNA::TargetSearch::SearchOptions->new( $self->{conf}{amirna}{configfile} );
		%local_dbs_description = $searchOptions->get_transcript_libraries();
	};
	if($@) {	
		$self->stash->{params} = process_error();
		$self->stash->{template} = $self->load_tmpl($self->plugin_conf('template_path').'/results.tmpl');
		return;
	}

	my @local_dbs             = sort { $local_dbs_description{$a} cmp $local_dbs_description{$b} } keys %local_dbs_description;
	$self->stash->{db_popup_menu} = $q->popup_menu(
            -name   => 'transcript_library',
            -id     => 'transcript_library',
            -values => \@local_dbs,
            -labels => \%local_dbs_description,
            -default=> $self->{conf}{amirna}{default_genome},
            -class  => 'form_widget',
        );

	# Set the form
	#
	# Add a POST form and hidden parameters
	$self->stash->{start_form} = $q->start_multipart_form;
	$self->stash->{hidden_fields} = $q->hidden('page', $self->{_plugin_name} )
		. $q->hidden('project', $self->get_current_project )
		. $q->hidden('rm', "compute" );
	$self->stash->{end_form} = $q->endform;

	$self->stash->{template} = $self->load_tmpl($self->plugin_conf('template_path').'/view.tmpl');

	return;
}

sub compute {
	my $self = shift;
	
	my $html;
	
	# Check for user input errors
	if(not $self->check_input_data) {
		# Redirect to form
		$self->showform();
	
		return;
	}
	
	# Get CGI query object
	my $q = $self->query();
	my $full_url = $q->url(-relative => 1) . "?page=" . ID;
	
	# Default user parameters
	my %user_param = (
		transcript_library  => "",
		fasta            	=> "",
	);
	
	# Collect parameters from ENV and add to user parameters
	foreach my $param ($q->param) {
		$user_param{$param} = $q->param($param);
	}
	
	foreach my $key (sort keys %user_param) {
		$html .= "<b>$key</b> => " . $user_param{$key} . "<br>";
	}
	$self->stash->{params} = blast($self, %user_param);
	$self->stash->{template} = $self->load_tmpl($self->plugin_conf('template_path').'/results.tmpl');
	
	return;
}

sub check_input_data {
	my $self = shift;
	my $q    = $self->query;

	my $err  = 1;

	if(! $q->param('transcript_library') ) {
		$self->stash->{error_msg} = $self->print_error_div("Please specify a Genome.");
		$err = 0;
	}
	if(! $q->param('fasta') ) {
		$self->stash->{error_msg} = $self->print_error_div("Please specify a Fasta sequence.");
		$err = 0;
	}
	
	return $err;
}
1;
